Crate betfair_xml_parser

Crate betfair_xml_parser 

Betfair XML file parser. The intended use is to parse the XML files and generate Rust structs that can be used to generate code for the Betfair API-NG in Rust (or other languages?)

Input: XML files from Betfair API-NG Output: Rust structs as representation of the XML files

Modules

common
Common elements of the XML files
data_type
Betfair XML file tag parser
exception_type
Betfair XML file tag parser
operation
Betfair XML file tag parser
simple_type
Betfair XML file <simpleType tag parser

Structs

Interface
Top level representation of the XML file

Enums

InterfaceItems
A child item of the tag

Functions

parse_interface
Parse the XML file into a Rust struct