Crate betfair_xml_parser

Betfair XML file parser. The intended use is to parse the XML files and generate Rust structs that can be used to generate code for the Betfair API-NG in Rust (or other languages?)

Input: XML files from Betfair API-NG Output: Rust structs as representation of the XML files

Modules

Structs

  • Top level representation of the XML file

Enums

Functions